/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.organisation.workingdays.api;

import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Collection;
import org.apache.fineract.infrastructure.core.data.EnumOptionData;

/**
 * Created by sanyam on 19/8/17.
 */

final class WorkingDaysApiResourceSwagger {

    private WorkingDaysApiResourceSwagger() {

    }

    @Schema(description = "GetWorkingDaysResponse")
    public static final class GetWorkingDaysResponse {

        private GetWorkingDaysResponse() {

        }

        @Schema(example = "1")
        public Long id;
        @Schema(example = "FREQ=WEEKLY;INTERVAL=1;BYDAY=MO,TU,WE,TH,FR")
        public String recurrence;
        public EnumOptionData repaymentRescheduleType;
        @Schema(example = "true")
        public Boolean extendTermForDailyRepayments;
    }

    @Schema(description = "GetWorkingDaysTemplateResponse")
    public static final class GetWorkingDaysTemplateResponse {

        private GetWorkingDaysTemplateResponse() {

        }

        public Collection<EnumOptionData> repaymentRescheduleOptions;
    }

    @Schema(description = "PutWorkingDaysRequest")
    public static final class PutWorkingDaysRequest {

        private PutWorkingDaysRequest() {

        }

        @Schema(example = "FREQ=WEEKLY;INTERVAL=1;BYDAY=MO,TU,WE,TH,FR")
        public String recurrence;
        @Schema(example = "en")
        public String locale;
        @Schema(example = "4")
        public EnumOptionData repaymentRescheduleType;
        @Schema(example = "true")
        public Boolean extendTermForDailyRepayments;
    }

    @Schema(description = "PutWorkingDaysResponse")
    public static final class PutWorkingDaysResponse {

        private PutWorkingDaysResponse() {

        }

        @Schema(example = "1")
        public Long resourceId;
    }
}
