/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.portfolio.note.exception;

import org.apache.fineract.infrastructure.core.exception.AbstractPlatformResourceNotFoundException;
import org.springframework.dao.EmptyResultDataAccessException;

/**
 * A {@link RuntimeException} thrown when note resources are not found.
 */
public class NoteNotFoundException extends AbstractPlatformResourceNotFoundException {

    public NoteNotFoundException(final Long id) {
        super("error.msg.note.id.invalid", "Note with identifier " + id + " does not exist", id);
    }

    public NoteNotFoundException(final Long id, final Long resourceId, final String resource) {
        super("error.msg." + resource + ".note.id.invalid",
                "Note with identifier " + id + " does not exist for " + resource + " with identifier " + resourceId, id, resourceId);
    }

    public NoteNotFoundException(Long id, Long resourceId, String resource, EmptyResultDataAccessException e) {
        super("error.msg." + resource + ".note.id.invalid",
                "Note with identifier " + id + " does not exist for " + resource + " with identifier " + resourceId, id, resourceId, e);
    }

}
